geom v1.0.0 Geom.Ai.Astar

A* implementation for a navigation mesh.

Summary

Functions

Returns a path from the start vector to the goal vector along the nav mesh if it exists

Functions

get_path(nav_mesh, start, goal)

Returns a path from the start vector to the goal vector along the nav mesh if it exists.